@@ -362,11 +362,12 @@ class Wiki():
 
     def logevents(self, start=None, end=None,
         event_type=None,
+        direction='older', # or newer
     ):
         q = {
             'list': 'logevents',
             'lelimit': LIST_LIMIT,
-            'ledir': 'older', # newer changes first
+            'ledir': direction,
         }
         if start and end and start < end:
             start, end = end, start # newer changes first, remember?
