@@ -1,7 +1,8 @@
+from datetime import datetime
 import sys
 import os
 
-from bwikibot.api import Wiki
+from bwikibot.api import Wiki, datetime2zulu
 from bwikibot.ui import shift_block
 
 SESSION_FILE = 'cli.session'
@@ -116,4 +117,7 @@ def write_page(*args):
 
     wiki.page(name).write(''.join(text), 'cli editing')
 
-
+@action('now')
+def get_now():
+    ''' Prints current ISO-formatted zulu time '''
+    print(datetime2zulu(datetime.utcnow()))
