@@ -7,6 +7,7 @@ import sys
 
 from bwikibot.cli import get_wiki, action
 from bwikibot.api import datetime2zulu, zulu2datetime, WikiError
+from bwikibot.api import Change
 
 from . import licenses
 
@@ -76,23 +77,18 @@ def main(start_from, limit):
 
 def get_uploads(wiki, start):
     if debug: # faking uploads
-        from bwikibot.api import Change
         yield Change(wiki, dict(
             title='Файл:Remainder-pattern1.png',
             timestamp=datetime2zulu(
-                datetime.now() - wait_before_check * 2
+                datetime.utcnow() - wait_before_check * 2
             ),
             user='BunykBot',
         ))
     else:
-        for upload in wiki.logevents(
-                event_type='upload',
-                end=datetime.now() - timedelta(days=2)
-        ):
-            yield upload
         start = zulu2datetime(start) if start else None
         for upload in wiki.logevents(
                 event_type='upload', start=start,
+                direction='newer',
         ):
             yield upload
 
@@ -100,7 +96,7 @@ counter = 0
 
 def check_upload(upload, limit):
     global counter
-    if upload.time + wait_before_check > datetime.now():
+    if upload.time + wait_before_check > datetime.utcnow():
         return
     print('Checking image {} uploaded at {} by {}'.format(
         upload.page.title,
@@ -139,7 +135,7 @@ def mark_image(page, summary):
 def check_category(wiki):
     if check_category.created:
         return
-    now = datetime.now()
+    now = datetime.utcnow()
     name = category_by_date % {
         'day': now.day,
         'month': month_names[now.month],
