@@ -1,6 +1,7 @@
 '''
 User interface utilities
 '''
+#from mako.template import Template
 
 def print_diff(text_a, text_b):
     ''' Print difference between two values '''
@@ -32,3 +33,21 @@ def shift_block(block, spaces):
     lines = block.splitlines()
     lines = [' ' * spaces + line.strip() for line in lines]
     return '\n'.join(lines).strip()
+
+def link(text):
+    print(text)
+    if isinstance(text, tuple):
+        text = '|'.join(text)
+    return '[[{}]]'.format(text) if text else text
+
+def link_list(items, separator=', '):
+    if isinstance(items, str):
+        items = eval(items)
+    return separator.join(map(link, items))
+
+def render(template, **kwargs):
+    return Template(template).render(
+        link=link,
+        link_list=link_list,
+        **kwargs
+    )
